as.scidb(X, name = tmpnam(), chunksize, overlap, start, chunkSize, gc=TRUE, ...)chunksize argument, for backwards compatibility -- use chunksize instead)df2scidb (see df2scidb).scidb reference object. as.scidb function creates a single-attribute SciDB array named
name and copies the data from X into it, returning a scidb
object reference to the new array. The SciDB array will be 1-D if X is a
vector, and 2-D if X is a matrix. Data are transferred using a binary
representation.If X is a data.frame, then as.scidb creates a one-dimensional
multi-attribute SciDB array, with SciDB attributes representing each column
of the data.frame. A utitlity function called df2scidb is used for
data.frame uploads--the functions as.scidb and df2scidb are equivalent
in this use case. Note that data frame data are transferred using a text
representation.
This function supports double-precision, integer (32-bit), logical, and single-character array attribute types.
scidb
df2scidb
## Not run:
# X <- matrix(runif(20),5)
# A <- as.scidb(X)
# as.scidb(iris)
# scidblist()
# print(A)
# ## End(Not run)
Run the code above in your browser using DataLab