na.locf in Package scidb"na.locf"(object, along=dimensions(object)[1],fill_sparse=FALSE,`eval`=FALSE)scidb or scidbdf object.scidb reference object. na.locf function from the zoo package, the SciDB
na.locf function fills in both missing (SciDB null values) and
empty (SciDB sparse) values with the last non-missing and non-sparse value
along the indicated dimension.Time series represented in SciDB are often sparse arrays. The na.locf
function defines a conveniet way to fill in all missing values along the time
coordinate axis down to the time resolution.
Caution! If fill_sparse=TRUE then
the output array is a mostly dense, filled-in version of the input
array. If the time resolution is very fine and the input array very sparse,
then the output array can be huge. Consider using regrid first on
very fine time scales to reduce their resolution.