scidb-class: Class "scidb"
Description
A class that represents SciDB arrays as R arrays.Objects from the Class
Objects can be created by calls of the form new("scidb", ...),
scidb("ARRAY_NAME", ...), or as.scidb(R_MATRIX, ...).Notes
SciDB arrays are general n-dimensional sparse arrays with integer dimensions.
The scidb class represents SciDB arrays in a way that mimics standard R
arrays in many ways. The scidbdf class represents one-dimensional SciDB
arrays with one or more attributes that mimic R data frames.Matrix arithmetic operations are overloaded for 2-D numeric arrays.