The scidb package provides basic functions that move data between R and SciDB and issue SciDB queries.
The package defines two R classes that facilitate programming with
SciDB. The scidb class defines an n-dimensional sparse array
class. The scidbdf class defines a data frame class. Data
for scidb and scidbdf objects are backed by the
SciDB database and operations on them are conducted by SciDB.
| Package: |
| scidb |
| Type: |
| Package |
| Version: |
| 0.0 |
| Date: |
| 2012-07-18 |
| License: |
| GPL3 |
| Depends: |
| methods |
options(scidb.index.sequence.limit=1000000) Maximum allowed sequential index limit (for larger use between)
options(scidb.max.array.elements=100000000) Maximum allowed elements in an array return result
options(scidb.version=13.9) The scidb.version option is set during scidbconnect(). However, users may carefully override it to enable certain bug fixes specific to older versions of SciDB
options(scidb.gemm_chunk_size=1000) Default gemm chunk size
options(scidb.default_shim_port=8080L) Default shim port
options(scidb.default_shim_host="localhost") Default shim host
options(scidb.safe_remove=TRUE) Require force=TRUE to remove non-session arrays
options(scidb.verifyhost=FALSE) Set TRUE to reverse host lookup in SSL sessions
options(scidb.interrupt=TRUE) Set FALSE to disable user interruptable HTTP transactions
options(scidb.stream=FALSE) Set TRUE to enable streaming data through the shim interface to SciDB (avoids copying query output data to a file on the server), see https://github.com/Paradigm4/shim.