scidbconnect(host=options("scidb.default_shim_host")[[1]],
port=options("scidb.default_shim_port")[[1]],
username, password)scidb
package. We internalize state to facilitate operations involving scidb
objects.Thus, only one open SciDB connection is supported at a time.
One may connect to and use multiple SciDB databases by sequentially calling
scidbconnect between operations. Note that scidb objects are not
valid across different SciDB databases.
Use the optional username and password arguments to authenticate
the connection with the shim service. Authenticated connections require
an encrypted connection with shim, available by default on port 8083.