scidbconnect(host=options("scidb.default_shim_host")[[1]], port=options("scidb.default_shim_port")[[1]], username, password, auth_type=c("pam","digest"), protocol=c("http","https"))auth_type parameter is only used when a username and
password are supplied. It defaults to 'pam'
which uses local Linux user names and passwords on the SciDB system.
Select 'digest' to use basic HTTP digest authentication. See the
shim documentation for details
http://htmlpreview.github.io/?https://raw.github.com/Paradigm4/shim/master/wwwroot/help.html.scidb
package. We internalize state to facilitate operations involving scidb
objects.Thus, only one open SciDB connection is supported at a time.
One may connect to and use multiple SciDB databases by sequentially calling
scidbconnect between operations. Note that scidb objects are not
valid across different SciDB databases.
Use the optional username and password arguments to authenticate
the connection with the shim service. PAM-authenticated connections require
an encrypted connection with shim, available by default on port 8083.
Use the optional username and password arguments with
auth_type set to "digest" to use HTTP digest authentication (see the
shim documentation to configur this). Digest authentication may use either
"http" or "https" transports selected by the protocol setting.